pub struct NetworkConfig { /* private fields */ }Expand description
A network configuration, composed of a relaychain, parachains and HRMP channels.
Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
Sourcepub fn global_settings(&self) -> &GlobalSettings
pub fn global_settings(&self) -> &GlobalSettings
The global settings of the network.
Sourcepub fn relaychain(&self) -> &RelaychainConfig
pub fn relaychain(&self) -> &RelaychainConfig
The relay chain of the network.
Sourcepub fn parachains(&self) -> Vec<&ParachainConfig>
pub fn parachains(&self) -> Vec<&ParachainConfig>
The parachains of the network.
Sourcepub fn hrmp_channels(&self) -> Vec<&HrmpChannelConfig>
pub fn hrmp_channels(&self) -> Vec<&HrmpChannelConfig>
The HRMP channels of the network.
Sourcepub fn custom_processes(&self) -> Vec<&CustomProcess>
pub fn custom_processes(&self) -> Vec<&CustomProcess>
The Custom process to spawn
Sourcepub fn dump_to_toml(&self) -> Result<String, Error>
pub fn dump_to_toml(&self) -> Result<String, Error>
A helper function to dump the network configuration to a TOML string.
Sourcepub fn load_from_toml_with_settings(
path: &str,
settings: &GlobalSettings,
) -> Result<NetworkConfig, Error>
pub fn load_from_toml_with_settings( path: &str, settings: &GlobalSettings, ) -> Result<NetworkConfig, Error>
A helper function to load a network configuration from a TOML file.
Sourcepub fn load_from_toml(path: &str) -> Result<NetworkConfig, Error>
pub fn load_from_toml(path: &str) -> Result<NetworkConfig, Error>
A helper function to load a network configuration from a TOML file.
Sourcepub fn load_from_toml_string(toml_data: &str) -> Result<NetworkConfig, Error>
pub fn load_from_toml_string(toml_data: &str) -> Result<NetworkConfig, Error>
A helper function to load a network configuration from a TOML string.
Relative paths (e.g. command = "./bin/polkadot") are resolved against the current
working directory, since there is no configuration file to use as base. Use
NetworkConfig::load_from_toml_string_with_base_dir to resolve them against a
specific directory instead.
Sourcepub fn load_from_toml_string_with_base_dir(
toml_text: &str,
base_dir: &Path,
) -> Result<NetworkConfig, Error>
pub fn load_from_toml_string_with_base_dir( toml_text: &str, base_dir: &Path, ) -> Result<NetworkConfig, Error>
A helper function to load a network configuration from a TOML string, resolving
relative paths (e.g. command = "./bin/polkadot") against base_dir.